@@ -83,16 +83,23 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 	def __init__(self, scope, _id, tool, config, data_urls, **kwargs):
 		self.tool = tool
 		self.config = config
-		self.data_buckets = [
-			data_url for data_url in data_urls if data_url.startswith('s3')
-		]
-		self.data_urls = [
-			data_url for data_url in data_urls if not data_url.startswith('s3')
-		]
+
 		self.leader_name = ''
 		self.nodes = []
 		self.use_https = self.config['aws'].get('https', False)
 
+		self.data_urls = [
+			data_url for data_url in data_urls if not data_url.startswith('s3')
+		]
+		self.data_buckets = [
+			data_url.split('|') for data_url in data_urls if data_url.startswith('s3')
+		]
+		for bucket in self.data_buckets:
+			if len(bucket) < 2:
+				bucket.append('*')
+		print(self.data_buckets)
+		raise Exception('bleh')
+
 		self.tool.upload_to_s3()
 
 		super().__init__(scope, _id, **kwargs)
@@ -170,7 +177,7 @@ class _AWSStack(Stack):  # pylint: disable=too-many-instance-attributes
 				f'aws s3 sync s3://{self.config["aws"]["bucket"]} /mnt/efs',
 				'mkdir -p /mnt/efs/data',
 				'cd /mnt/efs/data',
-				*[f'aws s3 sync {data_bucket} /mnt/efs/data' for data_bucket in self.data_buckets],  # noqa: E501
+				*[f'aws s3 sync {data_bucket[0]} /mnt/efs/data --exclude "*" --include "{data_bucket[1]}"' for data_bucket in self.data_buckets],  # noqa: E501
 				*[f'curl -O {data_url}' for data_url in self.data_urls],
 				'cd -'
 			)
